@@ -6,7 +6,7 @@ from .client import MerkleApiClient
 
 if sys.version_info >= (3, 8):
     from importlib import metadata as importlib_metadata
-else:
+else:  # pragma: no cover
     import importlib_metadata
 
 
