@@ -7,6 +7,7 @@ import time
 import canonicaljson
 import requests
 from eth_account.account import Account
+from eth_account.datastructures import SignedMessage
 from eth_account.messages import encode_defunct
 from eth_account.signers.local import LocalAccount
 from pydantic import NoneStr, PositiveInt
@@ -72,7 +73,7 @@ class MerkleApiClient:
             self.config.base_path + path, params=params, json=json, headers=headers
         ).json()
         if "errors" in response:
-            raise Exception(response["errors"])
+            raise Exception(response["errors"])  # pragma: no cover
         return response
 
     def _post(
@@ -88,7 +89,7 @@ class MerkleApiClient:
             self.config.base_path + path, params=params, json=json, headers=headers
         ).json()
         if "errors" in response:
-            raise Exception(response["errors"])
+            raise Exception(response["errors"])  # pragma: no cover
         return response
 
     def _put(
@@ -104,7 +105,7 @@ class MerkleApiClient:
             self.config.base_path + path, params=params, json=json, headers=headers
         ).json()
         if "errors" in response:
-            raise Exception(response["errors"])
+            raise Exception(response["errors"])  # pragma: no cover
         return response
 
     def _delete(
@@ -120,7 +121,7 @@ class MerkleApiClient:
             self.config.base_path + path, params=params, json=json, headers=headers
         ).json()
         if "errors" in response:
-            raise Exception(response["errors"])
+            raise Exception(response["errors"])  # pragma: no cover
         return response
 
     def _check_auth_header(self):
@@ -183,27 +184,24 @@ class MerkleApiClient:
         body = AuthPutRequest(params=auth_params)
         response = requests.put(
             "https://api.farcaster.xyz/v2/auth",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
             headers={"Authorization": header},
         ).json()
         return AuthPutResponse(**response).result
 
-    def delete_auth(self, timestamp: PositiveInt) -> StatusResponse:
+    def delete_auth(self) -> StatusContent:
         """Delete an access token
 
-        Args:
-            timestamp (PositiveInt): The timestamp of the access
-                token to delete
-
         Returns:
-            StatusResponse: Status of the deletion
+            StatusContent: Status of the deletion
         """
+        timestamp = now_ms()
         body = AuthDeleteRequest(params=Timestamp(timestamp=timestamp))
         response = self._delete(
             "auth",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
+        return StatusResponse(**response).result
 
     def get_cast_likes(
         self,
@@ -227,37 +225,37 @@ class MerkleApiClient:
         )
         return CastReactionsGetResponse(**response).result
 
-    def like_cast(self, body: CastHash) -> ReactionsResult:
+    def like_cast(self, cast_hash: str) -> ReactionsPutResult:
         """Like a given cast
 
         Args:
-            body (CastHash): hash of the cast to like
+            cast_hash (str): hash of the cast to like
 
         Returns:
-            ReactionsResult: Result of liking the cast
+            ReactionsPutResult: Result of liking the cast
         """
+        body = CastHash(cast_hash=cast_hash)
         response = self._put(
             "cast-likes",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
         return CastReactionsPutResponse(**response).result
 
-    def delete_cast_likes(self, cast_hash: str, body: CastHash) -> StatusResponse:
+    def delete_cast_likes(self, cast_hash: str) -> StatusContent:
         """Remove a like from a cast
 
         Args:
             cast_hash (str): hash of the cast to unlike
-            body (CastHash): hash of the cast to unlike
 
         Returns:
-            StatusResponse: Status of the deletion
+            StatusContent: Status of the deletion
         """
+        body = CastHash(cast_hash=cast_hash)
         response = self._delete(
             "cast-likes",
-            params={"castHash": cast_hash},
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
+        return StatusResponse(**response).result
 
     def get_cast_recasters(
         self,
@@ -339,95 +337,44 @@ class MerkleApiClient:
         )
         return CastsGetResponse(**response).result
 
-    def post_cast(self, body: CastsPostRequest) -> CastContent:
+    def post_cast(
+        self,
+        text: str,
+        embeds: Optional[List[AnyUrl]] = None,
+        parent: Optional[Parent] = None,
+    ) -> CastContent:
         """Post a cast to Farcaster
 
         Args:
-            body (CastsPostRequest): The cast data structure
+            text (str): text of the cast
+            embeds (Optional[List[AnyUrl]], optional): list of embeds, defaults to None
+            parent (Optional[Parent], optional): parent of the cast, defaults to None
 
         Returns:
             CastContent: The result of posting the cast
         """
+        body = CastsPostRequest(text=text, embeds=embeds, parent=parent)
         response = self._post(
             "casts",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
         return CastsPostResponse(**response).result
 
-    def delete_cast(self, cast_hash: str) -> StatusResponse:
+    def delete_cast(self, cast_hash: str) -> StatusContent:
         """Delete a cast
 
         Args:
             cast_hash (str): the hash of the cast to delete
 
         Returns:
-            StatusResponse: Status of the deletion
+            StatusContent: Status of the deletion
         """
         body = CastHash(cast_hash=cast_hash)
         response = self._delete(
             "casts",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
-
-    def get_collection(self, collection_id: str) -> CollectionResult:
-        """Get a specific collection
-
-        Args:
-            collection_id (str): OpenSea collection ID
-
-        Returns:
-            CollectionResult: collection
-        """
-        response = self._get(
-            "collection",
-            params={"collectionId": collection_id},
-        )
-        return CollectionGetResponse(**response).result
-
-    def get_collection_activity(
-        self,
-        collection_id: str,
-        cursor: NoneStr = None,
-        limit: PositiveInt = 25,
-    ) -> EventsResult:
-        """Get collection activity
-
-        Args:
-            collection_id (str): OpenSea collection ID
-            cursor (NoneStr, optional): cursor, defaults to None
-            limit (PositiveInt, optional): limit, defaults to 25
-
-        Returns:
-            EventsResult: Model containing events
-        """
-        response = self._get(
-            "collection-activity",
-            params={"collectionId": collection_id, "cursor": cursor, "limit": limit},
-        )
-        return CollectionActivityGetResponse(**response).result
-
-    def get_collection_assets(
-        self,
-        collection_id: str,
-        cursor: NoneStr = None,
-        limit: PositiveInt = 25,
-    ) -> AssetsResult:
-        """Get assets in an OpenSea collection
-
-        Args:
-            collection_id (str): OpenSea collection ID
-            cursor (NoneStr, optional): cursor, defaults to None
-            limit (PositiveInt, optional): limit, defaults to 25
-
-        Returns:
-            AssetsResult: model containing assets
-        """
-        response = self._get(
-            "collection-assets",
-            params={"collectionId": collection_id, "cursor": cursor, "limit": limit},
-        )
-        return CollectionAssetsGetResponse(**response).result
+        return StatusResponse(**response).result
 
     def get_collection_owners(
         self,
@@ -495,37 +442,37 @@ class MerkleApiClient:
         )
         return FollowingGetResponse(**response).result
 
-    def follow_user(self, fid: PositiveInt) -> StatusResponse:
+    def follow_user(self, fid: PositiveInt) -> StatusContent:
         """Follow a user
 
         Args:
             fid (PositiveInt): Farcaster ID of the user to follow
 
         Returns:
-            StatusResponse: Status of the follow
+            StatusContent: Status of the follow
         """
         body = FollowsPutRequest(target_fid=fid)
         response = self._put(
             "follows",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
+        return StatusResponse(**response).result
 
-    def unfollow_user(self, fid: PositiveInt) -> StatusResponse:
+    def unfollow_user(self, fid: PositiveInt) -> StatusContent:
         """Unfollow a user
 
         Args:
             fid (PositiveInt): Farcaster ID of the user to unfollow
 
         Returns:
-            StatusResponse: Status of the unfollow
+            StatusContent: Status of the unfollow
         """
         body = FollowsDeleteRequest(target_fid=fid)
         response = self._delete(
             "follows",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
+        return StatusResponse(**response).result
 
     def get_me(self) -> UserResult:
         """Get the current user
@@ -572,25 +519,25 @@ class MerkleApiClient:
         body = CastHash(cast_hash=cast_hash)
         response = self._put(
             "recasts",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
         return RecastsPutResponse(**response).result
 
-    def delete_recast(self, cast_hash: str) -> StatusResponse:
+    def delete_recast(self, cast_hash: str) -> StatusContent:
         """Delete a recast
 
         Args:
             cast_hash (str): the cast hash
 
         Returns:
-            StatusResponse: Status of the recast deletion
+            StatusContent: Status of the recast deletion
         """
         body = CastHash(cast_hash=cast_hash)
         response = self._delete(
             "recasts",
-            json=body.dict(by_alias=True),
+            json=body.dict(by_alias=True, exclude_none=True),
         )
-        return StatusResponse(**response)
+        return StatusResponse(**response).result
 
     def get_user(self, fid: int) -> UserResult:
         """Get a user
@@ -811,16 +758,18 @@ class MerkleApiClient:
         if not self.wallet:
             raise Exception("Wallet not set")
         auth_put_request = AuthPutRequest(params=params)
-        payload = auth_put_request.dict(by_alias=True)
+        payload = auth_put_request.dict(by_alias=True, exclude_none=True)
         encoded_payload = canonicaljson.encode_canonical_json(payload)
         signable_message = encode_defunct(primitive=encoded_payload)
-        signed_message = self.wallet.sign_message(signable_message)
+        signed_message: SignedMessage = self.wallet.sign_message(signable_message)
         data_hex_array = bytearray(signed_message.signature)
         encoded = base64.b64encode(data_hex_array).decode()
         return f"Bearer eip191:{encoded}"
 
 
-def get_wallet(mnemonic: NoneStr, private_key: NoneStr) -> Optional[LocalAccount]:
+def get_wallet(
+    mnemonic: NoneStr = None, private_key: NoneStr = None
+) -> Optional[LocalAccount]:
     """Get a wallet from mnemonic or private key
 
     Args:
@@ -834,10 +783,10 @@ def get_wallet(mnemonic: NoneStr, private_key: NoneStr) -> Optional[LocalAccount
 
     if mnemonic:
         account: LocalAccount = Account.from_mnemonic(mnemonic)
-        return account
+        return account  # pragma: no cover
     elif private_key:
         account = Account.from_key(private_key)
-        return account
+        return account  # pragma: no cover
     return None
 
 
